Discover Packages
github.com/srz-zumix/git-use-commit-times
cmd
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jan 26, 2026
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Execute adds all child commands to the root command and sets flags appropriately.
This is called by main.main(). It only needs to happen once to the rootCmd.
func SetLogLevel(level string )
SetLogLevel sets the log level
Source Files
¶
Click to show internal directories.
Click to hide internal directories.